@@ -23,7 +23,7 @@ import re, os
 
 
 # The current version of rdiff-backup
-version = "0.12.3"
+version = "0.12.4"
 
 # If this is set, use this value in seconds as the current time
 # instead of reading it from the clock.
@@ -53,9 +53,6 @@ process_gid = os.getgid()
 # If true, when copying attributes, also change target's uid/gid
 change_ownership = None
 
-# If true, when copying attributes, also change target's permission.
-change_permissions = 1
-
 # If true, change the permissions of unwriteable mirror files
 # (such as directories) so that they can be written, and then
 # change them back.  This defaults to 1 just in case the process
